==> resource_planner-0.4.1.gem: app/controllers/resource_planner/resources_controller.rb <==
require_dependency 'resource_planner/application_controller'

module ResourcePlanner
  class ResourcesController < ApplicationController
    def list
      @resources = Hash.new
      get_resource_models.each do |resource_model|
        resource_data = (resource_model[:data_query].nil? || resource_model[:data_query].empty?) ?
        resource_model[:model].constantize.all :
        eval(resource_model[:data_query])

        @resources[resource_model] = resource_data
      end

      respond_to do |format|
        format.html # list.html.erb
        #format.html { render ('list.html.erb') }
        format.xml  { render :xml => @resources }
        format.json { render ('list.json.jbuilder') }
        #format.json { render :json => @resources }
      end
    end

    def events
      @resource_models = get_resource_models
      @events = ::ResourcePlanner::Event.events

      respond_to do |format|
        format.html # events.html.erb
        #format.html { render ('events.html.erb') }
        format.xml  { render :xml => @events }
        format.json { render ('events.json.jbuilder') }
        #format.json { render :json => @events }
      end
    end

    def restrictions
      @resource_models = get_resource_models
      @events = ::ResourcePlanner::Event.resource_restrictions

      respond_to do |format|
        format.html # events.html.erb
        #format.html { render ('restrictions.html.erb') }
        format.xml  { render :xml => @events }
        format.json { render ('restrictions.json.jbuilder') }
        #format.json { render :json => @events }
      end
    end

  end
end

==> resource_planner-0.4.2.gem: app/controllers/resource_planner/resources_controller.rb <==
require_dependency 'resource_planner/application_controller'

module ResourcePlanner
  class ResourcesController < ApplicationController
    def list
      @resources = {}
      get_resource_models.each do |resource_model|
        resource_data = if resource_model[:data_query].nil? || resource_model[:data_query].empty?
                          resource_model[:model].constantize.all
                        else
                          eval(resource_model[:data_query])
                        end

        @resources[resource_model] = resource_data
      end

      respond_to do |format|
        format.html # list.html.erb
        #format.html { render ('list.html.erb') }
        format.xml  { render :xml => @resources }
        format.json { render 'list.json.jbuilder' }
        #format.json { render :json => @resources }
      end
    end

    def events
      @resource_models = get_resource_models
      @events = ::ResourcePlanner::Event.events

      respond_to do |format|
        format.html # events.html.erb
        #format.html { render ('events.html.erb') }
        format.xml  { render :xml => @events }
        format.json { render 'events.json.jbuilder' }
        #format.json { render :json => @events }
      end
    end

    def restrictions
      @resource_models = get_resource_models
      @events = ::ResourcePlanner::Event.resource_restrictions

      respond_to do |format|
        format.html # events.html.erb
        #format.html { render ('restrictions.html.erb') }
        format.xml  { render :xml => @events }
        format.json { render 'restrictions.json.jbuilder' }
        #format.json { render :json => @events }
      end
    end

  end
end
